package logique;
import java.io.*;
import java.util.Vector;
/**
 * AttributDecl represente la liste des attributs 
 * d'une balise Xml 
 * @author Gros Pierre Emmanuel
 *         <a href="mailto:gros@limsi.fr">gros@limsi.fr</a>
 * @version 6.0
 */
public class AttributDecl implements Serializable
{

/**
 * Le nom de la balise
 */
protected String _aname;
 /**
  * Le type de la balise (required , fixed,imply)
  */
protected int _type;
 /**
  * La valeur par default
  */
protected String _valueDefault;
 /**
  * La valeur de l'attribut
  */
protected String _value;
 /**
  * Dans le cas ou on a une liste de valeur possible 
  */
protected Vector _valueVect;
 /**
  * reserve
  */
protected String _clause;
 /**
  * Cette balise a t elle une valeur ou une liste de valeur possible
  */
protected boolean _enum ;

/**
 * Attribut Decl prend en parametre
 * Ce constructeur construit un attribut pouvant contenir une valeur libre
 * @param  aName    le nom de l'attribut 
 * @param  type    son type
 * @param  valueDefault la valeur par default 
 * @param  value  la valeur 
 * @param  clause    ,sa clause
 * 
 */
public AttributDecl( String aName,
	       int type, String valueDefault, String value
	       ,String clause )
{   
if (aName!=null) _aname=new String(aName);
 _type=type;
if (valueDefault!=null) _valueDefault=new String (valueDefault);
if (value!=null) _value=new String (value);
if (clause!=null) _clause=new String (clause);
_enum=false;
}

/**
 * Attribut Decl prend en parametre 
 * Ce constructeur construit un attribut pouvant contenir une valeur parmis une liste
 * @param  aName    le nom de l'attribut 
 * @param  type    son type
 * @param  valueDefault la valeur par default 
 * @param  value  la valeur 
 * @param  clause    sa clause
 * @param  valueListe la liste des valeurs possible  
 */
 
public AttributDecl( String aName,
	       int type, String valueDefault, String value
	       ,String clause ,Vector valueListe)
{   
if (aName!=null) _aname=new String(aName);
_type=type;
if (valueDefault!=null) _valueDefault=new String (valueDefault);
if (value!=null) _value=new String (value);
if (clause!=null) _clause=new String (clause);
_valueVect=valueListe;
_enum=true;

}
/**
 * renvoie la valeur par default de l'attribut
 * @result  la valeur par defaut
 */
public String getValueDefault(){return _valueDefault;}
/** 
 * Renvoie le nom de l'attribut
 * @result  le nom de l'attribut
 */
public String getName(){return _aname;}
/**
 * Convertit le type de l'attribut en chaine de caractere
 * @param type le type de l'attribut
 * @result  le type de l'attribut sous forme d'une chaine de caractere(IMPLIED|REQUIRED|FIXED)
 */
public static String getTypeS(int type)
{
switch (type)
{
case 0: return new String("IMPLIED");
case 1:return new String ("REQUIRED");
case 2:return new String ("FIXED");
default:return new String("IMPLIED");
}
}
/**
 * Renvoie le type de l'attribut
 * @result  le type de l'attribut
 */
public int getType(){return _type;}
/**
 * Renvoie la valeur de l'attribut
 * @result  la valeur de l'attribut
 */
public String getValue(){return _value;}
/** 
 * Reserver
 */
public String getClause(){return _clause;}
/** 
 * Renvoie vrai si la valeur de l'attribut est prise dans une liste
 * @result  vrai si il s'agit d'une enumeration
 */
public boolean getEnum(){return _enum;}
/**
 * Renvoie la liste des valeurs possibles pour l'attribut
 * @result un vecteur de chaine de caractere contenant les valeurs
 */
public Vector getValueListe(){return _valueVect;}
/**
 * Met a jour l'attribut _valueVect
 * @param valueVect le nouveau vecteur
 */
public void setValueListe(Vector valueVect){ _valueVect=valueVect;}

/**
 * Fonction d'affichage de la classe
 * @result une chaine de caractere reprensentant l'objet
 */
public String toString()
{
String result=new String();
if (_aname!=null) result=result+"["+_aname+"]";
 result=result+"["+_type+"]";
if (_valueDefault!=null) result=result+"["+_valueDefault+"]";
if (_value!=null) result=result+"["+_value+"]";
return result;
}
/** 
 * implementation de la serialisation pour l'object
 */
private void writeObject(java.io.ObjectOutputStream out)
     throws IOException
     {
     if (_aname==null) _aname=new String();

if (_valueDefault==null) _valueDefault=new String();
if (_value==null) _value=new String();
if (_clause==null) _clause=new String();
    
     	out.writeUTF(_aname);
     	out.writeInt(_type);
     	out.writeUTF(_valueDefault);
     	out.writeUTF(_value);
     	out.writeUTF(_clause);
     }
/**
 * implementation de la serialization pour la classe
 */
private void readObject(java.io.ObjectInputStream in)
     throws IOException, ClassNotFoundException
     {
     	_aname = in.readUTF();
	_type = in.readInt();
	_valueDefault= in.readUTF();
	_value= in.readUTF();
	_clause= in.readUTF();
	
if (_aname.length()==0) _aname=null;

if (_valueDefault.length()==0) _valueDefault=null;
if (_value.length()==0) _value=null;
if (_clause.length()==0) _value=null;

}

}